import { NgModule } from '@angular/core';
import { Routes, RouterModule } from '@angular/router';
import { environment } from '@env/environment';
// layout
import { LayoutDefaultComponent } from '../layout/default/default.component';
import { LayoutFullScreenComponent } from '../layout/fullscreen/fullscreen.component';
import { LayoutPassportComponent } from '../layout/passport/passport.component';
// dashboard pages
import { DashboardV1Component } from './dashboard/v1/v1.component';
import { DashboardAnalysisComponent } from './dashboard/analysis/analysis.component';
import { DashboardMonitorComponent } from './dashboard/monitor/monitor.component';
import { DashboardWorkplaceComponent } from './dashboard/workplace/workplace.component';
import { ReportComponent } from './report/report.component';
import { UserLoginComponent } from './passport/login/login.component';

import { ForecastingWarningComponent } from './forecasting-warning/forecasting-warning.component';
import { PollutionManagementComponent } from './pollution/management/management.component';
import { EnvironmentManagementComponent } from './environment/management/management.component';
import { GridTraceComponent } from './grid-trace/grid-trace.component';
import { ImageGrabbingComponent } from './raise-dust/image-grabbing/image-grabbing.component';
import { SandTableComponent } from './sand-table/sand-table.component';
import { RaiseDustComponent } from './raise-dust/raise-dust.component';
import { RealTimeComponent } from './raise-dust/real-time/real-time.component';
import { StatisticalQueryComponent } from './raise-dust/statistical-query/statistical-query.component';

const routes: Routes = [
    {
        path: '',
        component: LayoutDefaultComponent,
        children: [
            { path: "", redirectTo: "home-page", pathMatch: "full" },
            {
              path: "home-page",
              loadChildren: "./home-page/home-page.module#HomePageModule"
            },
            {
              path: "enterprise-management",
              loadChildren: "./enterprise-management/enterprise-management.module#EnterpriseManagementModule"
            },
            { path: 'statistics', loadChildren: './statistics/statistics.module#StatisticsModule' },
            { path: 'forecasting-warning', component: ForecastingWarningComponent },
            { path: 'pollution/management', component: PollutionManagementComponent },
            { path: 'environment/management', component: EnvironmentManagementComponent },
            { path: 'grid-trace', component: GridTraceComponent },
            { path: 'reports', loadChildren: './reports/reports.module#ReportsModule' },
            {
                path: "operation",
                loadChildren: "./operation/operation.module#OperationModule"
            },
            { path: 'sand-table', component: SandTableComponent },
            { path: 'raise-dust', component: RaiseDustComponent },
            { path: 'raise-dust/real-time', component: RealTimeComponent },
            { path: 'raise-dust/statistical-query', component: StatisticalQueryComponent },
            { path: 'raise-dust/image-grabbing', component: ImageGrabbingComponent },
        ]
    },    // passport
    {
        path: 'passport',
        component: LayoutPassportComponent,
        children: [
            {data: {title: '登录页面'}, path: 'login', component: UserLoginComponent }
        ]
    },    // passport
    {
      path: 'report',
      component: ReportComponent,
      data: {title: '报表展示'}
    },
    { path: '**', redirectTo: 'passport/login' }
];

@NgModule({
    imports: [RouterModule.forRoot(routes, { useHash: environment.useHash })],
    exports: [RouterModule]
  })
export class RouteRoutingModule { }
